# Providers

Providers are the modules or remote services that provide the data that the AGiXT uses to generate the reports. The AGiXT can use multiple providers at the same time, and each provider can be configured to use different credentials and settings.

For example: OpenAI, Google Bard, Microsoft Bing, GPT4Free are remote providers. GPT4All, llamacpp, and Oobabooga are local providers that runs on your computer/server.